@@ -14,6 +14,7 @@ __PACKAGE__->mk_classdata(
         end_privileged_cmd
     /]
 );
+
 __PACKAGE__->mk_classdata(
     configure_phrases => [qw/
         configure_prompt
@@ -157,15 +158,20 @@ sub end_privileged {
     # XXX: don't try to optimise away this print() and waitfor() into a cmd()
     # because they are needed to get the $match back!
 
-    $self->print($self->pb->fetch('end_privileged_cmd'));
-    my (undef, $match) = $self->waitfor($self->prompt)
-        or $self->error('Failed to get prompt after leaving privileged mode');
+#    $self->print($self->pb->fetch('end_privileged_cmd'));
+#    my (undef, $match) = $self->waitfor($self->prompt)
+#        or $self->error('Failed to get prompt after leaving privileged mode');
+#
+#    # fairly dumb check to see that we're actually out of privileged
+#    # and back at a regular prompt
+#
+#    $self->error('Failed to leave privileged mode')
+#        if $match !~ eval 'qr'. $self->pb->fetch('basic_prompt');
 
-    # fairly dumb check to see that we're actually out of privileged
-    # and back at a regular prompt
-
-    $self->error('Failed to leave privileged mode')
-        if $match !~ eval 'qr'. $self->pb->fetch('basic_prompt');
+    $self->cmd(
+    	String => $self->pb->fetch('end_privileged_cmd'),
+	Match  => [$self->pb->fetch('basic_prompt')],
+    );
 
     $self->in_privileged_mode(0);
 
